#' CompRiskRel: Generalized Reliability and Competing Risks Analysis under Hybrid Censoring
#'
#' @description
#' Provides comprehensive tools for data generation, Maximum Likelihood Estimation (MLE),
#' Bayesian estimation (Gibbs sampling, Metropolis-Hastings), Importance Sampling,
#' Lindley approximation, stress-strength reliability estimation, optimal designs,
#' and reliability acceptance sampling plans under Type-I, Type-II, and generalized
#' (progressive) hybrid censoring schemes.
#'
#' @docType package
#' @name CompRiskRel-package
#' @aliases CompRiskRel
#' @keywords internal
"_PACKAGE"
