% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gen_data.R
\name{gen_gen_prog_hybrid}
\alias{gen_gen_prog_hybrid}
\title{Generate Data under Generalized Progressive Hybrid Censoring Scheme}
\usage{
gen_gen_prog_hybrid(
  pdf,
  cdf,
  lower = 0,
  upper = Inf,
  n,
  m,
  k,
  T_star,
  R_plan,
  seed = NULL
)
}
\arguments{
\item{pdf}{Probability density function.}

\item{cdf}{Cumulative distribution function.}

\item{lower}{Lower bound of support.}

\item{upper}{Upper bound of support.}

\item{n}{Total sample size.}

\item{m}{Target number of failures.}

\item{k}{Threshold failure count.}

\item{T_star}{Termination time limit.}

\item{R_plan}{Progressive censoring plan vector of length m.}

\item{seed}{Optional integer random seed for reproducibility.}
}
\value{
A list containing observed failure times, progressive removal plan, and censoring details.
}
\description{
Generate Data under Generalized Progressive Hybrid Censoring Scheme
}
\examples{
gen_gen_prog_hybrid(
  pdf = function(x) dexp(x, rate = 1),
  cdf = function(x) pexp(x, rate = 1),
  lower = 0, upper = 10, n = 20, m = 10,
  k = 5, T_star = 1.2, R_plan = rep(1, 10),
  seed = 123
)
}
