% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bayes_approx.R
\name{lindley_approx_censored}
\alias{lindley_approx_censored}
\title{Lindley Asymptotic Approximation for Posterior Expectations}
\usage{
lindley_approx_censored(log_lik, log_prior, init_par)
}
\arguments{
\item{log_lik}{Log-likelihood function of parameter vector.}

\item{log_prior}{Log-prior density function of parameter vector.}

\item{init_par}{Maximum likelihood estimate or posterior mode.}
}
\value{
List with Lindley posterior estimates and standard errors.
}
\description{
Lindley Asymptotic Approximation for Posterior Expectations
}
\examples{
lindley_approx_censored(
  log_lik = function(th) -sum((c(1.2, 0.8, 1.5) - th[1])^2),
  log_prior = function(th) dexp(th[1], rate = 1, log = TRUE),
  init_par = c(1.1)
)
}
