% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/optimal_design.R
\name{optimal_design_hybrid}
\alias{optimal_design_hybrid}
\title{Optimal Design Selection for Hybrid Censoring Schemes}
\usage{
optimal_design_hybrid(
  n,
  r_candidates,
  T_candidates,
  pdf,
  cdf,
  par,
  criterion = c("D-optimal", "A-optimal", "cost")
)
}
\arguments{
\item{n}{Sample size.}

\item{r_candidates}{Candidate failure count choices.}

\item{T_candidates}{Candidate time limit choices.}

\item{pdf}{Probability density function of lifetime distribution.}

\item{cdf}{Cumulative distribution function of lifetime distribution.}

\item{par}{Model parameters.}

\item{criterion}{Optimization criterion: "D-optimal" (maximize determinant of Fisher Information), "A-optimal" (minimize trace of inverse Fisher Information), or "cost".}
}
\value{
List containing optimal choice of (r, T) and associated information measure.
}
\description{
Optimal Design Selection for Hybrid Censoring Schemes
}
\examples{
optimal_design_hybrid(
  n = 20, r_candidates = c(5, 10, 15), T_candidates = c(0.5, 1.0, 1.5),
  pdf = function(x, th) dexp(x, rate = th[1]),
  cdf = function(x, th) pexp(x, rate = th[1]),
  par = c(1.0), criterion = "D-optimal"
)
}
