% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CompRiskRel-package.R
\docType{package}
\name{CompRiskRel-package}
\alias{CompRiskRel-package}
\alias{CompRiskRel}
\title{CompRiskRel: Generalized Reliability and Competing Risks Analysis under Hybrid Censoring}
\description{
Provides comprehensive tools for data generation, Maximum Likelihood Estimation (MLE),
Bayesian estimation (Gibbs sampling, Metropolis-Hastings), Importance Sampling,
Lindley approximation, stress-strength reliability estimation, optimal designs,
and reliability acceptance sampling plans under Type-I, Type-II, and generalized
(progressive) hybrid censoring schemes.
}
\author{
\strong{Maintainer}: Shikhar Tyagi \email{shikhar1093tyagi@gmail.com} (\href{https://orcid.org/0000-0003-1606-0844}{ORCID})

Authors:
\itemize{
  \item Arvind Pandey \email{arvindmzu@gmail.com}
  \item Bhupendra Singh \email{bhupendra.rana@gmail.com}
  \item Vrijesh Tripathi \email{vrijesh.tripathi@uwi.edu}
}

}
\keyword{internal}
