% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sampling_plans.R
\name{sampling_plan_weibull}
\alias{sampling_plan_weibull}
\title{Reliability Acceptance Sampling Plan for Weibull Distribution (10.5.2)}
\usage{
sampling_plan_weibull(
  n,
  T_star,
  r,
  beta_shape,
  alpha = 0.05,
  beta = 0.1,
  theta0,
  theta1
)
}
\arguments{
\item{n}{Sample size.}

\item{T_star}{Termination time.}

\item{r}{Minimum failure limit.}

\item{beta_shape}{Known shape parameter of Weibull distribution.}

\item{alpha}{Producer's risk.}

\item{beta}{Consumer's risk.}

\item{theta0}{AQL scale parameter.}

\item{theta1}{RQL scale parameter.}
}
\value{
S3 object of class \code{sampling_plan}.
}
\description{
Reliability Acceptance Sampling Plan for Weibull Distribution (10.5.2)
}
\examples{
sampling_plan_weibull(
  n = 25, T_star = 1.5, r = 12, beta_shape = 1.5,
  alpha = 0.05, beta = 0.10, theta0 = 3.0, theta1 = 1.0
)
}
