% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gen_data.R
\name{gen_stress_strength}
\alias{gen_stress_strength}
\title{Generate Data for Stress-Strength Reliability Models}
\usage{
gen_stress_strength(
  pdf_X,
  cdf_X,
  pdf_Y,
  cdf_Y,
  lower_X = 0,
  upper_X = Inf,
  lower_Y = 0,
  upper_Y = Inf,
  n_X,
  n_Y,
  censoring_type = c("type1_hybrid", "type2_hybrid", "prog_hybrid"),
  r_X = NULL,
  T_X = NULL,
  r_Y = NULL,
  T_Y = NULL,
  seed = NULL
)
}
\arguments{
\item{pdf_X}{Density function for stress X.}

\item{cdf_X}{Cumulative distribution function for stress X.}

\item{pdf_Y}{Density function for strength Y.}

\item{cdf_Y}{Cumulative distribution function for strength Y.}

\item{lower_X}{Lower bound for X.}

\item{upper_X}{Upper bound for X.}

\item{lower_Y}{Lower bound for Y.}

\item{upper_Y}{Upper bound for Y.}

\item{n_X}{Sample size for stress X.}

\item{n_Y}{Sample size for strength Y.}

\item{censoring_type}{Censoring scheme.}

\item{r_X}{Minimum required failures for X.}

\item{T_X}{Time cutoff for X.}

\item{r_Y}{Minimum required failures for Y.}

\item{T_Y}{Time cutoff for Y.}

\item{seed}{Optional random seed.}
}
\value{
A list containing generated stress dataset X and strength dataset Y.
}
\description{
Generate Data for Stress-Strength Reliability Models
}
\examples{
gen_stress_strength(
  pdf_X = function(x) dexp(x, rate = 1.2),
  cdf_X = function(x) pexp(x, rate = 1.2),
  pdf_Y = function(y) dexp(y, rate = 0.8),
  cdf_Y = function(y) pexp(y, rate = 0.8),
  n_X = 20, n_Y = 20,
  censoring_type = "type1_hybrid",
  r_X = 12, T_X = 1.2, r_Y = 12, T_Y = 1.5, seed = 123
)
}
