% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{summary.mle_fit}
\alias{summary.mle_fit}
\title{Summary Method for MLE Fit Objects}
\usage{
\method{summary}{mle_fit}(object, ...)
}
\arguments{
\item{object}{Object of class \code{mle_fit}.}

\item{...}{Unused additional parameters.}
}
\value{
A matrix summary of parameter estimates, standard errors, z-values, and p-values.
}
\description{
Summary Method for MLE Fit Objects
}
