% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plots.R
\name{plot.comp_risk_rel_data}
\alias{plot.comp_risk_rel_data}
\title{Plot Method for Objects of Class comp_risk_rel_data}
\usage{
\method{plot}{comp_risk_rel_data}(x, ...)
}
\arguments{
\item{x}{Object of class \code{comp_risk_rel_data}.}

\item{...}{Additional graphical parameters.}
}
\value{
No return value, called for side effects.
}
\description{
Plot Method for Objects of Class comp_risk_rel_data
}
