% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stress_strength.R
\name{stress_strength_rel}
\alias{stress_strength_rel}
\title{Stress-Strength Reliability Estimation R = P(X < Y)}
\usage{
stress_strength_rel(
  data_X,
  data_Y,
  pdf_X,
  cdf_X,
  pdf_Y,
  cdf_Y,
  init_par_X,
  init_par_Y,
  method = "BFGS"
)
}
\arguments{
\item{data_X}{Object of class \code{comp_risk_rel_data} for stress X.}

\item{data_Y}{Object of class \code{comp_risk_rel_data} for strength Y.}

\item{pdf_X}{Density function for X.}

\item{cdf_X}{CDF function for X.}

\item{pdf_Y}{Density function for Y.}

\item{cdf_Y}{CDF function for Y.}

\item{init_par_X}{Initial parameter value for X.}

\item{init_par_Y}{Initial parameter value for Y.}

\item{method}{Optimization method.}
}
\value{
S3 object containing parameter estimates, estimated reliability R = P(X < Y), standard error, and asymptotic confidence interval.
}
\description{
Stress-Strength Reliability Estimation R = P(X < Y)
}
\examples{
dat <- gen_stress_strength(
  pdf_X = function(x) dexp(x, rate = 1.2), cdf_X = function(x) pexp(x, rate = 1.2),
  pdf_Y = function(y) dexp(y, rate = 0.8), cdf_Y = function(y) pexp(y, rate = 0.8),
  lower_X = 0, upper_X = 10, lower_Y = 0, upper_Y = 10,
  n_X = 20, n_Y = 20, censoring_type = "type1_hybrid",
  r_X = 12, T_X = 1.2, r_Y = 12, T_Y = 1.5, seed = 123
)
stress_strength_rel(
  data_X = dat$data_X, data_Y = dat$data_Y,
  pdf_X = function(x, th) dexp(x, rate = th[1]), cdf_X = function(x, th) pexp(x, rate = th[1]),
  pdf_Y = function(y, th) dexp(y, rate = th[1]), cdf_Y = function(y, th) pexp(y, rate = th[1]),
  init_par_X = c(1.0), init_par_Y = c(0.7), method = "BFGS"
)
}
