% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mle_est.R
\name{mle_gen_prog_hybrid}
\alias{mle_gen_prog_hybrid}
\title{Maximum Likelihood Estimation under Generalized Progressive Hybrid Censoring}
\usage{
mle_gen_prog_hybrid(
  data,
  pdf,
  cdf,
  init_par,
  R_plan = NULL,
  method = "BFGS",
  lower = -Inf,
  upper = Inf
)
}
\arguments{
\item{data}{Object of class \code{comp_risk_rel_data}.}

\item{pdf}{Density function.}

\item{cdf}{CDF function.}

\item{init_par}{Initial parameter values.}

\item{R_plan}{Progressive removal vector.}

\item{method}{Maximization algorithm.}

\item{lower}{Lower parameter bound.}

\item{upper}{Upper parameter bound.}
}
\value{
S3 object of class \code{mle_fit}.
}
\description{
Maximum Likelihood Estimation under Generalized Progressive Hybrid Censoring
}
\examples{
dat <- gen_gen_prog_hybrid(
  pdf = function(x) dexp(x, rate = 1),
  cdf = function(x) pexp(x, rate = 1),
  lower = 0, upper = 10, n = 20, m = 10, k = 5,
  T_star = 1.2, R_plan = rep(1, 10), seed = 123
)
mle_gen_prog_hybrid(
  data = dat,
  pdf = function(x, theta) dexp(x, rate = theta[1]),
  cdf = function(x, theta) pexp(x, rate = theta[1]),
  init_par = c(0.8), R_plan = rep(1, 10), method = "BFGS"
)
}
